/*
 *  jDTAUS Core RI Servlet Container
 *  Copyright (c) 2005 Christian Schulte (cs@jdtaus.org)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.servlet;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class ServletFilterBundle
{

  /** Singleton instance. */
  private static final ServletFilterBundle instance =
    new ServletFilterBundle();

  /** Creates a new {@code ServletFilterBundle} instance. */
  ServletFilterBundle()
  {
    this.getMessage ( "systemPropertyWarning", Locale.getDefault() );
  }

  /**
   * Gets the {@code ServletFilterBundle} singleton.
   *
   * @return the {@code ServletFilterBundle} singleton.
   */
  static ServletFilterBundle getInstance()
  {
    return instance;
  }

  /**
   * Gets the text of the message with key {@code "systemPropertyWarning"}.
   *
   * @return <pre>
   * System property {0} set to {1}.</pre>
   */
  String getSystemPropertyWarningText ( final Locale locale )
  {
    return this.getMessage ( "systemPropertyWarning", locale );
  }

  /**
   * Gets the message with key {@code "systemPropertyWarning"}.
   *
   * @return <pre>
   * System property {0} set to {1}.</pre>
   */
  MessageFormat getSystemPropertyWarningMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "systemPropertyWarning", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/ri/servlet/ServletFilter",
                                     locale ).getString( key );

  }
}
